@@ -4,24 +4,30 @@
 #' 
 #' \code{type = "ac"} plots cost-effectiveness acceptability
 #' curves, \code{type = "ce"} plots results on the 
-#' cost-efficiency plane, \code{type = "cov"} to perform
-#' covariance analysis on the results.
+#' cost-efficiency plane, \code{type = "cov"} to perform 
+#' covariance analysis on the results, \code{type = "evpi"} 
+#' for expected value of perfect information.
 #' 
 #' @param x Result from \code{\link{run_model}}.
 #' @param type Type of plot, see details.
 #' @param max_wtp Maximal willingness to pay.
-#' @param n Number of CECA points to estimate (values above
+#' @param n Number of CECA points to estimate (values above 
 #'   100 may take significant time).
 #' @param log_scale Show willingness to pay on a log scale?
+#' @param diff Logical, perform covariance analysis on
+#'   strategy differences?
+#' @param threshold When \code{diff = TRUE}, threshlod value
+#'   for net monetary benefit computation.
 #' @param bw Black & white plot for publications?
-#' @param ... Additional arguments passed to \code{plot}.
+#' @param ... Additional arguments, depends on \code{type}.
 #'   
 #' @return A \code{ggplot2} object.
 #' @export
 #' 
-plot.psa <- function(x, type = c("ce", "ac", "cov"),
+plot.psa <- function(x, type = c("ce", "ac", "cov", "evpi"),
                      max_wtp = 1e5,
                      n = 100, log_scale = TRUE,
+                     diff = FALSE, threshold,
                      bw = FALSE, ...) {
   type <- match.arg(type)
   
@@ -78,8 +84,30 @@ plot.psa <- function(x, type = c("ce", "ac", "cov"),
       
       res
     },
+    evpi = {
+      values <- generate_wtp(max_wtp = max_wtp,
+                             n = n, log_scale = log_scale)
+      tab <- compute_evpi(x, values)
+      
+      res <- ggplot2::ggplot(tab,
+                             ggplot2::aes_string(
+                               x = ".ceac",
+                               y = ".evpi"
+                             )) +
+        ggplot2::geom_line() +
+        ggplot2::xlab("Willingness to pay") +
+        ggplot2::ylab("EVPI") +
+        ggplot2::ylim(0, NA)
+      
+      if (log_scale) {
+        res <- res +
+          ggplot2::scale_x_log10()
+      }
+      
+      res
+    },
     cov = {
-      tab <- compute_cov(x) %>% 
+      tab <- compute_cov(x, diff = diff, threshold = threshold, ...) %>% 
         dplyr::mutate_(
           .prop = ~ .prop * 100
         )
