@@ -38,6 +38,10 @@ print.uneval_model <- function(x, ...) {
 #' efficiency frontier, and \code{type = "values"} state
 #' values per cycle.
 #' 
+#' When \code{states} is specified, the states will be turned into
+#' a factor with the ordering given in the variable, so that
+#' plotting order can be controlled.
+#' 
 #' @return A \code{ggplot2} object.
 #' 
 #' @example inst/examples/example_plot.run_model.R
@@ -76,11 +80,12 @@ plot.run_model <- function(x, type = c("counts", "ce", "values"),
       if (! is.null(states)) {
         if (any(pb <- ! states %in% get_state_names(x))) {
           stop(sprintf(
-            "Some state do not exist: %s.",
+            "Some states do not exist: %s.",
             paste(states[pb], collapse = ", ")
           ))
         }
         tab <- tab[tab$state_names %in% states, ]
+        tab$state_names <- factor(tab$state_names, levels = states)
       }
       
       if (! is.null(strategy)) {
@@ -149,11 +154,12 @@ plot.run_model <- function(x, type = c("counts", "ce", "values"),
       if (! is.null(values)) {
         if (any(pb <- ! values %in% get_state_value_names(x))) {
           stop(sprintf(
-            "Some state do not exist: %s.",
+            "Some values do not exist: %s.",
             paste(values[pb], collapse = ", ")
           ))
         }
         tab <- tab[tab$value_names %in% values, ]
+        tab$value_names <- factor(tab$value_names, levels = values)
       }
       
       if (! is.null(strategy)) {
