@@ -22,29 +22,29 @@ state_B <- define_state(
 state_B
 
 ## ------------------------------------------------------------------------
-strat_1 <- define_strategy(
-  transition_matrix = mat_trans,
+strat <- define_strategy(
+  transition = mat_trans,
   state_A,
   state_B
 )
-strat_1
+strat
 
 ## ------------------------------------------------------------------------
-res_mod_1 <- run_model(
-  strat_1,
+res_mod <- run_model(
+  strat,
   cycles = 10,
   cost = cost,
   effect = utility
 )
-res_mod_1
+res_mod
 
 ## ---- fig.width = 6, fig.height=4, fig.align='center'--------------------
-plot(res_mod_1)
+plot(res_mod)
 
 ## ---- fig.align='center', fig.height=4, fig.width=6, message=FALSE-------
 library(ggplot2)
 
-plot(res_mod_1) +
+plot(res_mod) +
   xlab("Time") +
   ylab("N") +
   theme_minimal() +
@@ -53,9 +53,14 @@ plot(res_mod_1) +
     palette = "Set1"
   )
 
+## ---- fig.align='center', fig.height=4, fig.width=6, message=FALSE-------
+library(ggplot2)
+
+plot(res_mod, bw = TRUE)
+
 ## ------------------------------------------------------------------------
-get_counts(res_mod_1)
-get_values(res_mod_1)
+head(get_counts(res_mod))
+head(get_values(res_mod))
 
 ## ------------------------------------------------------------------------
 rate_to_prob(r = 162, per = 1000, to = 5)
